==> blesta-5.10.2.zip: blesta/language/de_de/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Batch-Prozess';
$lang['AdminBilling.batch.field_passphrase'] = 'Passphrase';
$lang['AdminBilling.batch.text_description'] = 'Geben Sie Ihre Passphrase ein, um alle für die automatische Abbuchung vorgesehenen Rechnungen mit einem lokal gespeicherten Zahlungskonto manuell zu verarbeiten.';
$lang['AdminBilling.batch.no_passphrase'] = 'Die manuelle Stapelverarbeitung ist nicht aktiviert.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Stapel';
$lang['AdminBilling.batch.page_title'] = 'Fakturierungscharge';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Markierung Gedruckt';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Drucken';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Datum gesendet';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Datum Fällig';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Datum der Abrechnung';
$lang['AdminBilling.printqueue.heading_due'] = '.';
$lang['AdminBilling.printqueue.heading_paid'] = 'Bezahlt';
$lang['AdminBilling.printqueue.heading_amount'] = 'Betrag';
$lang['AdminBilling.printqueue.heading_client'] = 'Kunde #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Invoice #';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Es gibt keine Rechnungen in der Warteschlange zum Drucken.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Es gibt keine zuvor gedruckten Rechnungen.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Druck-Warteschlange';
$lang['AdminBilling.printqueue.category_printed'] = 'Zuvor gedruckt';
$lang['AdminBilling.printqueue.category_to_print'] = 'Drucken';
$lang['AdminBilling.printqueue.page_title'] = 'Druckwarteschlange für Rechnungen';
$lang['AdminBilling.invoices.text_edit'] = 'bearbeiten';
$lang['AdminBilling.invoices.applied_no_results'] = 'Auf diese Rechnung werden keine Transaktionen angewendet.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Optionen';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Angewandt auf';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Angewandt';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Betrag';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Zahlungsart';
$lang['AdminBilling.transactions.applied_no_results'] = 'Diese Transaktion wurde nicht auf Rechnungen angewandt.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Angewandt auf';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Betrag';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Rechnung';
$lang['AdminBilling.transactions.no_results'] = 'Es gibt keine Transaktionen mit diesem Status.';
$lang['AdminBilling.transactions.option_edit'] = 'bearbeiten';
$lang['AdminBilling.transactions.category_returned'] = 'Zurückgeschickt';
$lang['AdminBilling.transactions.category_refunded'] = 'Erstattet';
$lang['AdminBilling.transactions.category_pending'] = 'Anhängig';
$lang['AdminBilling.transactions.category_error'] = 'Fehler';
$lang['AdminBilling.transactions.category_voided'] = 'Ungültig';
$lang['AdminBilling.transactions.category_declined'] = 'Abgelehnt';
$lang['AdminBilling.transactions.category_approved'] = 'Genehmigt';
$lang['AdminBilling.transactions.heading_options'] = 'Optionen';
$lang['AdminBilling.transactions.heading_date'] = 'Datum';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Referenz #';
$lang['AdminBilling.transactions.heading_number'] = 'Nummer';
$lang['AdminBilling.transactions.heading_applied'] = 'Angewandt';
$lang['AdminBilling.transactions.heading_credit'] = 'Anerkannt';
$lang['AdminBilling.transactions.heading_amount'] = 'Betrag';
$lang['AdminBilling.transactions.heading_type'] = 'Typ';
$lang['AdminBilling.transactions.heading_client'] = 'Kunde #';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transaktionen';
$lang['AdminBilling.transactions.page_title'] = 'Abrechnungstransaktionen';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Grund für die Stornierung: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Dieser Dienst hat keine Details.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Einreichen';
$lang['AdminBilling.services.action.field_client'] = 'Kunde:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push zum Client';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Nicht abbrechen';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Bestimmtes Datum';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Ende der Amtszeit';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Stornierung des Zeitplans';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Es gibt keine Dienste mit diesem Status.';
$lang['AdminBilling.services.text_never'] = 'Niemals';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Geplant';
$lang['AdminBilling.services.category_in_review'] = 'Im Rückblick';
$lang['AdminBilling.services.category_pending'] = 'Anhängig';
$lang['AdminBilling.services.category_suspended'] = 'Aufgehängt';
$lang['AdminBilling.services.category_canceled'] = 'Abgesagt';
$lang['AdminBilling.services.category_active'] = 'Aktiv';
$lang['AdminBilling.services.confirm_delete'] = 'Sind Sie sicher, dass Sie diesen Dienst löschen möchten?';
$lang['AdminBilling.services.option_delete'] = 'Löschen';
$lang['AdminBilling.services.option_manage'] = 'Verwalten Sie';
$lang['AdminBilling.services.heading_options'] = 'Optionen';
$lang['AdminBilling.services.heading_datecanceled'] = 'Datum Storniert';
$lang['AdminBilling.services.heading_datesuspended'] = 'Datum der Aussetzung';
$lang['AdminBilling.services.heading_daterenews'] = 'Datum Erneuert';
$lang['AdminBilling.services.heading_dateadded'] = 'Datum hinzugefügt';
$lang['AdminBilling.services.heading_term'] = 'Begriff';
$lang['AdminBilling.services.heading_label'] = 'Etikett';
$lang['AdminBilling.services.heading_package'] = 'Paket';
$lang['AdminBilling.services.heading_client'] = 'Kunde #';
$lang['AdminBilling.services.boxtitle_services'] = 'Dienstleistungen';
$lang['AdminBilling.services.page_title'] = 'Abrechnungsdienste';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Zu diesem Angebot sind keine Rechnungen vorhanden.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Siehe';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Optionen';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Datum der Abrechnung';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Bezahlt';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Betrag';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Invoice #';
$lang['AdminBilling.quotations.no_results'] = 'Es gibt keine Zitate mit diesem Status.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Sind Sie sicher, dass Sie dieses Zitat genehmigen wollen?';
$lang['AdminBilling.quotations.option_approve'] = 'Genehmigen Sie';
$lang['AdminBilling.quotations.option_invoice'] = 'Rechnung erstellen';
$lang['AdminBilling.quotations.option_view'] = 'Siehe';
$lang['AdminBilling.quotations.option_edit'] = 'bearbeiten';
$lang['AdminBilling.quotations.heading_options'] = 'Optionen';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Verfallsdatum';
$lang['AdminBilling.quotations.heading_date_created'] = 'Datum der Erstellung';
$lang['AdminBilling.quotations.heading_total'] = 'Betrag';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Zwischensumme';
$lang['AdminBilling.quotations.heading_staff'] = 'Zitiert von';
$lang['AdminBilling.quotations.heading_title'] = 'Titel';
$lang['AdminBilling.quotations.heading_client'] = 'Kunde #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Zitat #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Zitate';
$lang['AdminBilling.quotations.page_title'] = 'Quoten für die Rechnungsstellung';
$lang['AdminBilling.invoices.no_results'] = 'Es sind keine Rechnungen mit diesem Status vorhanden.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s mal';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s Jahre';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s Monate';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s Wochen';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s Tage';
$lang['AdminBilling.invoices.term_year'] = '%1$s Jahr';
$lang['AdminBilling.invoices.term_month'] = '%1$s Monat';
$lang['AdminBilling.invoices.term_week'] = '%1$s Woche';
$lang['AdminBilling.invoices.term_day'] = '%1$s Tag';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +Steuer';
$lang['AdminBilling.invoices.option_pay'] = 'Bezahlen';
$lang['AdminBilling.invoices.option_view'] = 'Siehe';
$lang['AdminBilling.invoices.option_edit'] = 'bearbeiten';
$lang['AdminBilling.invoices.category_recurring'] = 'Wiederkehrende';
$lang['AdminBilling.invoices.category_pending'] = 'Anhängig';
$lang['AdminBilling.invoices.category_pastdue'] = 'Überfällig';
$lang['AdminBilling.invoices.category_voided'] = 'Ungültig';
$lang['AdminBilling.invoices.category_closed'] = 'Geschlossen';
$lang['AdminBilling.invoices.category_drafts'] = 'Entwürfe';
$lang['AdminBilling.invoices.category_open'] = 'Öffnen Sie';
$lang['AdminBilling.invoices.heading_count'] = 'Zählen Sie';
$lang['AdminBilling.invoices.heading_duration'] = 'Dauer';
$lang['AdminBilling.invoices.heading_term'] = 'Begriff';
$lang['AdminBilling.invoices.heading_options'] = 'Optionen';
$lang['AdminBilling.invoices.heading_datedue'] = 'Datum Fällig';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Datum der Abrechnung';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Datum abgeschlossen';
$lang['AdminBilling.invoices.heading_due'] = '.';
$lang['AdminBilling.invoices.heading_paid'] = 'Bezahlt';
$lang['AdminBilling.invoices.heading_amount'] = 'Betrag';
$lang['AdminBilling.invoices.heading_client'] = 'Kunde #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Wiederkehrend #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Invoice #';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Rechnungen';
$lang['AdminBilling.invoices.page_title'] = 'Fakturierung Rechnungen';
$lang['AdminBilling.managewidgets.text_author'] = 'Autor:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Ziehen Sie Widgets von rechts nach links, um sie zu Ihrer Rechnungsübersicht hinzuzufügen, oder von links nach rechts, um sie zu entfernen.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Wählen Sie unten ein Layout aus, um Ihre Rechnungsübersicht anzupassen.';
$lang['AdminBilling.index.action_batch'] = 'Ausstehende Posten Charge';
$lang['AdminBilling.index.action_printqueue'] = 'Noch nicht gedruckte Artikel';
$lang['AdminBilling.index.no_actions'] = 'Es stehen keine Maßnahmen an.';
$lang['AdminBilling.index.heading_actions'] = 'Aktionspunkte';
$lang['AdminBilling.index.customize_dashboard'] = 'Übersicht anpassen';
$lang['AdminBilling.index.manage_widgets'] = 'Widgets verwalten';
$lang['AdminBilling.index.page_title'] = 'Übersicht über die Rechnungsstellung';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'Das geplante Kündigungsdatum darf nicht in der Vergangenheit liegen.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Die eingegebene Passphrase ist ungültig.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Es wurden keine Rechnungen ausgewählt.';
$lang['AdminBilling.!success.services_pushed'] = 'Die ausgewählten Dienste wurden erfolgreich auf den neuen Mandanten übertragen.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'Die ausgewählten Dienste sind nicht mehr zur Stornierung vorgesehen.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Die ausgewählten Dienste wurden erfolgreich für die Stornierung eingeplant.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'Die ausgewählten Rechnungen wurden als gedruckt markiert.';

==> blesta-5.11.4.zip: blesta/language/de_de/admin_billing.php <==
<?php
/**
 * Admin Billing
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminBilling.batch.text_batchsubmit'] = 'Batch-Prozess';
$lang['AdminBilling.batch.field_passphrase'] = 'Passphrase';
$lang['AdminBilling.batch.text_description'] = 'Geben Sie Ihre Passphrase ein, um alle für die automatische Abbuchung vorgesehenen Rechnungen mit einem lokal gespeicherten Zahlungskonto manuell zu verarbeiten.';
$lang['AdminBilling.batch.no_passphrase'] = 'Die manuelle Stapelverarbeitung ist nicht aktiviert.';
$lang['AdminBilling.batch.boxtitle_batch'] = 'Stapel';
$lang['AdminBilling.batch.page_title'] = 'Fakturierungscharge';
$lang['AdminBilling.printqueue.text_marksubmit'] = 'Markierung Gedruckt';
$lang['AdminBilling.printqueue.text_printsubmit'] = 'Drucken';
$lang['AdminBilling.printqueue.heading_deliverydatesent'] = 'Datum gesendet';
$lang['AdminBilling.printqueue.heading_datedue'] = 'Datum Fällig';
$lang['AdminBilling.printqueue.heading_datebilled'] = 'Datum der Abrechnung';
$lang['AdminBilling.printqueue.heading_due'] = '.';
$lang['AdminBilling.printqueue.heading_paid'] = 'Bezahlt';
$lang['AdminBilling.printqueue.heading_amount'] = 'Betrag';
$lang['AdminBilling.printqueue.heading_client'] = 'Kunde #';
$lang['AdminBilling.printqueue.heading_invoice'] = 'Invoice #';
$lang['AdminBilling.printqueue.no_results_to_print'] = 'Es gibt keine Rechnungen in der Warteschlange zum Drucken.';
$lang['AdminBilling.printqueue.no_results_printed'] = 'Es gibt keine zuvor gedruckten Rechnungen.';
$lang['AdminBilling.printqueue.boxtitle_printqueue'] = 'Druck-Warteschlange';
$lang['AdminBilling.printqueue.category_printed'] = 'Zuvor gedruckt';
$lang['AdminBilling.printqueue.category_to_print'] = 'Drucken';
$lang['AdminBilling.printqueue.page_title'] = 'Druckwarteschlange für Rechnungen';
$lang['AdminBilling.invoices.text_edit'] = 'bearbeiten';
$lang['AdminBilling.invoices.applied_no_results'] = 'Auf diese Rechnung werden keine Transaktionen angewendet.';
$lang['AdminBilling.invoices.headingexpand_options'] = 'Optionen';
$lang['AdminBilling.invoices.headingexpand_appliedon'] = 'Angewandt auf';
$lang['AdminBilling.invoices.headingexpand_applied'] = 'Angewandt';
$lang['AdminBilling.invoices.headingexpand_amount'] = 'Betrag';
$lang['AdminBilling.invoices.headingexpand_paymenttype'] = 'Zahlungsart';
$lang['AdminBilling.transactions.applied_no_results'] = 'Diese Transaktion wurde nicht auf Rechnungen angewandt.';
$lang['AdminBilling.transactions.headingexpand_appliedon'] = 'Angewandt auf';
$lang['AdminBilling.transactions.headingexpand_amount'] = 'Betrag';
$lang['AdminBilling.transactions.headingexpand_invoice'] = 'Rechnung';
$lang['AdminBilling.transactions.no_results'] = 'Es gibt keine Transaktionen mit diesem Status.';
$lang['AdminBilling.transactions.option_edit'] = 'bearbeiten';
$lang['AdminBilling.transactions.category_returned'] = 'Zurückgeschickt';
$lang['AdminBilling.transactions.category_refunded'] = 'Erstattet';
$lang['AdminBilling.transactions.category_pending'] = 'Anhängig';
$lang['AdminBilling.transactions.category_error'] = 'Fehler';
$lang['AdminBilling.transactions.category_voided'] = 'Ungültig';
$lang['AdminBilling.transactions.category_declined'] = 'Abgelehnt';
$lang['AdminBilling.transactions.category_approved'] = 'Genehmigt';
$lang['AdminBilling.transactions.heading_options'] = 'Optionen';
$lang['AdminBilling.transactions.heading_date'] = 'Datum';
$lang['AdminBilling.transactions.heading_reference_id'] = 'Referenz #';
$lang['AdminBilling.transactions.heading_number'] = 'Nummer';
$lang['AdminBilling.transactions.heading_applied'] = 'Angewandt';
$lang['AdminBilling.transactions.heading_credit'] = 'Anerkannt';
$lang['AdminBilling.transactions.heading_amount'] = 'Betrag';
$lang['AdminBilling.transactions.heading_type'] = 'Typ';
$lang['AdminBilling.transactions.heading_client'] = 'Kunde #';
$lang['AdminBilling.transactions.boxtitle_transactions'] = 'Transaktionen';
$lang['AdminBilling.transactions.page_title'] = 'Abrechnungstransaktionen';
$lang['AdminBilling.serviceinfo.cancellation_reason'] = 'Grund für die Stornierung: %1$s';
$lang['AdminBilling.serviceinfo.no_results'] = 'Dieser Dienst hat keine Details.';
$lang['AdminBilling.services.field_actionsubmit'] = 'Einreichen';
$lang['AdminBilling.services.action.field_client'] = 'Kunde:';
$lang['AdminBilling.services.action.push_to_client'] = 'Push zum Client';
$lang['AdminBilling.services.action.field_action_type_none'] = 'Nicht abbrechen';
$lang['AdminBilling.services.action.field_action_type_date'] = 'Bestimmtes Datum';
$lang['AdminBilling.services.action.field_action_type_term'] = 'Ende der Amtszeit';
$lang['AdminBilling.services.action.schedule_cancellation'] = 'Stornierung des Zeitplans';
$lang['AdminBilling.services.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminBilling.services.no_results'] = 'Es gibt keine Dienste mit diesem Status.';
$lang['AdminBilling.services.text_never'] = 'Niemals';
$lang['AdminBilling.services.category_scheduled_cancellation'] = 'Geplant';
$lang['AdminBilling.services.category_in_review'] = 'Im Rückblick';
$lang['AdminBilling.services.category_pending'] = 'Anhängig';
$lang['AdminBilling.services.category_suspended'] = 'Aufgehängt';
$lang['AdminBilling.services.category_canceled'] = 'Abgesagt';
$lang['AdminBilling.services.category_active'] = 'Aktiv';
$lang['AdminBilling.services.confirm_delete'] = 'Sind Sie sicher, dass Sie diesen Dienst löschen möchten?';
$lang['AdminBilling.services.option_delete'] = 'Löschen';
$lang['AdminBilling.services.option_manage'] = 'Verwalten Sie';
$lang['AdminBilling.services.heading_options'] = 'Optionen';
$lang['AdminBilling.services.heading_datecanceled'] = 'Datum Storniert';
$lang['AdminBilling.services.heading_datesuspended'] = 'Datum der Aussetzung';
$lang['AdminBilling.services.heading_daterenews'] = 'Datum Erneuert';
$lang['AdminBilling.services.heading_dateadded'] = 'Datum hinzugefügt';
$lang['AdminBilling.services.heading_term'] = 'Begriff';
$lang['AdminBilling.services.heading_label'] = 'Etikett';
$lang['AdminBilling.services.heading_package'] = 'Paket';
$lang['AdminBilling.services.heading_client'] = 'Kunde #';
$lang['AdminBilling.services.boxtitle_services'] = 'Dienstleistungen';
$lang['AdminBilling.services.page_title'] = 'Abrechnungsdienste';
$lang['AdminBilling.quotationinvoices.invoices_no_results'] = 'Zu diesem Angebot sind keine Rechnungen vorhanden.';
$lang['AdminBilling.quotationinvoices.option_view'] = 'Siehe';
$lang['AdminBilling.quotationinvoices.headingexpand_options'] = 'Optionen';
$lang['AdminBilling.quotationinvoices.headingexpand_date_billed'] = 'Datum der Abrechnung';
$lang['AdminBilling.quotationinvoices.headingexpand_paid'] = 'Bezahlt';
$lang['AdminBilling.quotationinvoices.headingexpand_amount'] = 'Betrag';
$lang['AdminBilling.quotationinvoices.headingexpand_invoice'] = 'Invoice #';
$lang['AdminBilling.quotations.no_results'] = 'Es gibt keine Zitate mit diesem Status.';
$lang['AdminBilling.quotations.confirm_approve'] = 'Sind Sie sicher, dass Sie dieses Zitat genehmigen wollen?';
$lang['AdminBilling.quotations.option_approve'] = 'Genehmigen Sie';
$lang['AdminBilling.quotations.option_invoice'] = 'Rechnung erstellen';
$lang['AdminBilling.quotations.option_view'] = 'Siehe';
$lang['AdminBilling.quotations.option_edit'] = 'bearbeiten';
$lang['AdminBilling.quotations.heading_options'] = 'Optionen';
$lang['AdminBilling.quotations.heading_date_expires'] = 'Verfallsdatum';
$lang['AdminBilling.quotations.heading_date_created'] = 'Datum der Erstellung';
$lang['AdminBilling.quotations.heading_total'] = 'Betrag';
$lang['AdminBilling.quotations.heading_subtotal'] = 'Zwischensumme';
$lang['AdminBilling.quotations.heading_staff'] = 'Zitiert von';
$lang['AdminBilling.quotations.heading_title'] = 'Titel';
$lang['AdminBilling.quotations.heading_client'] = 'Kunde #';
$lang['AdminBilling.quotations.heading_quotation'] = 'Zitat #';
$lang['AdminBilling.quotations.boxtitle_quotations'] = 'Zitate';
$lang['AdminBilling.quotations.page_title'] = 'Quoten für die Rechnungsstellung';
$lang['AdminBilling.invoices.no_results'] = 'Es sind keine Rechnungen mit diesem Status vorhanden.';
$lang['AdminBilling.invoices.duration_infinite'] = '∞';
$lang['AdminBilling.invoices.duration_finite'] = '%1$s mal';
$lang['AdminBilling.invoices.term_year_plural'] = '%1$s Jahre';
$lang['AdminBilling.invoices.term_month_plural'] = '%1$s Monate';
$lang['AdminBilling.invoices.term_week_plural'] = '%1$s Wochen';
$lang['AdminBilling.invoices.term_day_plural'] = '%1$s Tage';
$lang['AdminBilling.invoices.term_year'] = '%1$s Jahr';
$lang['AdminBilling.invoices.term_month'] = '%1$s Monat';
$lang['AdminBilling.invoices.term_week'] = '%1$s Woche';
$lang['AdminBilling.invoices.term_day'] = '%1$s Tag';
$lang['AdminBilling.invoices.subtotal_w_tax'] = '%1$s +Steuer';
$lang['AdminBilling.invoices.option_pay'] = 'Bezahlen';
$lang['AdminBilling.invoices.option_view'] = 'Siehe';
$lang['AdminBilling.invoices.option_edit'] = 'bearbeiten';
$lang['AdminBilling.invoices.category_recurring'] = 'Wiederkehrende';
$lang['AdminBilling.invoices.category_pending'] = 'Anhängig';
$lang['AdminBilling.invoices.category_pastdue'] = 'Überfällig';
$lang['AdminBilling.invoices.category_voided'] = 'Ungültig';
$lang['AdminBilling.invoices.category_closed'] = 'Geschlossen';
$lang['AdminBilling.invoices.category_drafts'] = 'Entwürfe';
$lang['AdminBilling.invoices.category_open'] = 'Öffnen Sie';
$lang['AdminBilling.invoices.heading_count'] = 'Zählen Sie';
$lang['AdminBilling.invoices.heading_duration'] = 'Dauer';
$lang['AdminBilling.invoices.heading_term'] = 'Begriff';
$lang['AdminBilling.invoices.heading_options'] = 'Optionen';
$lang['AdminBilling.invoices.heading_datedue'] = 'Datum Fällig';
$lang['AdminBilling.invoices.heading_datebilled'] = 'Datum der Abrechnung';
$lang['AdminBilling.invoices.heading_dateclosed'] = 'Datum abgeschlossen';
$lang['AdminBilling.invoices.heading_due'] = '.';
$lang['AdminBilling.invoices.heading_paid'] = 'Bezahlt';
$lang['AdminBilling.invoices.heading_amount'] = 'Betrag';
$lang['AdminBilling.invoices.heading_client'] = 'Kunde #';
$lang['AdminBilling.invoices.heading_recurinvoice'] = 'Wiederkehrend #';
$lang['AdminBilling.invoices.heading_invoice'] = 'Invoice #';
$lang['AdminBilling.invoices.boxtitle_invoices'] = 'Rechnungen';
$lang['AdminBilling.invoices.page_title'] = 'Fakturierung Rechnungen';
$lang['AdminBilling.managewidgets.text_author'] = 'Autor:';
$lang['AdminBilling.managewidgets.text_version'] = 'ver %1$s';
$lang['AdminBilling.managewidgets.text_widgets'] = 'Ziehen Sie Widgets von rechts nach links, um sie zu Ihrer Rechnungsübersicht hinzuzufügen, oder von links nach rechts, um sie zu entfernen.';
$lang['AdminBilling.updatedashboard.text_layout'] = 'Wählen Sie unten ein Layout aus, um Ihre Rechnungsübersicht anzupassen.';
$lang['AdminBilling.index.action_batch'] = 'Ausstehende Posten Charge';
$lang['AdminBilling.index.action_printqueue'] = 'Noch nicht gedruckte Artikel';
$lang['AdminBilling.index.no_actions'] = 'Es stehen keine Maßnahmen an.';
$lang['AdminBilling.index.heading_actions'] = 'Aktionspunkte';
$lang['AdminBilling.index.customize_dashboard'] = 'Übersicht anpassen';
$lang['AdminBilling.index.manage_widgets'] = 'Widgets verwalten';
$lang['AdminBilling.index.page_title'] = 'Übersicht über die Rechnungsstellung';
$lang['AdminBilling.index.closed_parethesis'] = ')';
$lang['AdminBilling.index.open_parethesis'] = '(';
$lang['AdminBilling.!error.future_cancel_date'] = 'Das geplante Kündigungsdatum darf nicht in der Vergangenheit liegen.';
$lang['AdminBilling.!error.invalid_passphrase'] = 'Die eingegebene Passphrase ist ungültig.';
$lang['AdminBilling.!error.no_invoices_selected'] = 'Es wurden keine Rechnungen ausgewählt.';
$lang['AdminBilling.!success.services_pushed'] = 'Die ausgewählten Dienste wurden erfolgreich auf den neuen Mandanten übertragen.';
$lang['AdminBilling.!success.services_scheduled_uncancel'] = 'Die ausgewählten Dienste sind nicht mehr zur Stornierung vorgesehen.';
$lang['AdminBilling.!success.services_scheduled_cancel'] = 'Die ausgewählten Dienste wurden erfolgreich für die Stornierung eingeplant.';
$lang['AdminBilling.!success.invoices_marked_printed'] = 'Die ausgewählten Rechnungen wurden als gedruckt markiert.';
$lang['AdminBilling.services.action.field_suspension_reason'] = 'Grund für die Aussetzung:';
$lang['AdminBilling.services.action.unsuspend'] = 'Aufhängen';
$lang['AdminBilling.services.action.suspend'] = 'aussetzen.';
$lang['AdminBilling.!success.services_unsuspended'] = 'Die ausgewählten Dienste wurden erfolgreich freigeschaltet.';
$lang['AdminBilling.!success.services_suspended'] = 'Die ausgewählten Dienste wurden erfolgreich eingestellt.';
